@@ -5,7 +5,7 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     8-Oct-2019
-// Ver:      01-Oct-2021.
+// Ver:      31-Oct-2021.
 //
 //------------------------------------------------------------------------------
 //
@@ -2850,3 +2850,625 @@ char mul_unsigned_short_4_simd_ovfl(Py_ssize_t arraylen, unsigned short param, u
 #endif
 
 /*--------------------------------------------------------------------------- */
+
+/*--------------------------------------------------------------------------- */
+/* Initialise an SIMD vector with a specifired value.
+   initval = The value to initialise the vector to.
+   Returns the initalised SIMD vector. 
+*/
+#if defined(AF_HASSIMD_ARMv7_32BIT)
+float32x2_t initvec_float(float initval) {
+
+	unsigned int y;
+	float initvals[FLOATSIMDSIZE];
+	float32x2_t simdvec;
+
+	for (y = 0; y < FLOATSIMDSIZE; y++) {
+		initvals[y] = initval;
+	}
+	simdvec = vld1_f32((initvals));
+
+	return simdvec;
+}
+#endif
+
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   This version is without overflow checking.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   data3 = The third data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num_none
+#if defined(AF_HASSIMD_ARMv7_32BIT)
+void mul_float_1_simd(Py_ssize_t arraylen, float *data1, float param) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice;
+
+
+	// Initialise the comparison values.
+	datasliceright = initvec_float(param);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		// The actual SIMD operation. 
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data1[x],  resultslice);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data1[x] = data1[x] * param;
+	}
+
+}
+
+
+
+// param_arr_num_arr
+void mul_float_2_simd(Py_ssize_t arraylen, float *data1, float param, float *data3) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice;
+
+
+	// Initialise the comparison values.
+	datasliceright = initvec_float(param);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		// The actual SIMD operation. The compiler generates the correct instruction.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data3[x],  resultslice);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data3[x] = data1[x] * param;
+	}
+
+}
+
+
+
+// param_num_arr_none
+void mul_float_3_simd(Py_ssize_t arraylen, float param, float *data2) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice;
+
+
+	// Initialise the comparison values.
+	datasliceleft = initvec_float(param);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation. The compiler generates the correct instruction.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data2[x],  resultslice);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data2[x] = param * data2[x];
+	}
+
+}
+
+
+
+// param_num_arr_arr
+void mul_float_4_simd(Py_ssize_t arraylen, float param, float *data2, float *data3) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice;
+
+
+	// Initialise the comparison values.
+	datasliceleft = initvec_float(param);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation. The compiler generates the correct instruction.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data3[x],  resultslice);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data3[x] = param * data2[x];
+	}
+
+}
+
+
+
+// param_arr_arr_none
+void mul_float_5_simd(Py_ssize_t arraylen, float *data1, float *data2) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice;
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation. The compiler generates the correct instruction.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data1[x],  resultslice);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data1[x] = data1[x] * data2[x];
+	}
+
+}
+
+
+
+// param_arr_arr_arr
+void mul_float_6_simd(Py_ssize_t arraylen, float *data1, float *data2, float *data3) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice;
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation. The compiler generates the correct instruction.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data3[x],  resultslice);
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data3[x] = data1[x] * data2[x];
+	}
+
+}
+#endif
+
+/*--------------------------------------------------------------------------- */
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   This version is without overflow checking.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   data3 = The third data array.
+   param = The parameter to be applied to each array element.
+   Returns 1 if overflow occurred, else returns 0.
+*/
+// param_arr_num_none
+#if defined(AF_HASSIMD_ARMv7_32BIT)
+char mul_float_1_simd_ovfl(Py_ssize_t arraylen, float *data1, float param) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// Initialise the comparison values.
+	datasliceright = initvec_float(param);
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		// The actual SIMD operation. 
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data1[x],  resultslice);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, resultslice);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data1[x] = data1[x] * param;
+		if (!isfinite(data1[x])) {return 1;}
+	}
+
+	return 0;
+
+}
+
+
+
+// param_arr_num_arr
+char mul_float_2_simd_ovfl(Py_ssize_t arraylen, float *data1, float param, float *data3) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// Initialise the comparison values.
+	datasliceright = initvec_float(param);
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		// The actual SIMD operation.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data3[x],  resultslice);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, resultslice);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data3[x] = data1[x] * param;
+		if (!isfinite(data3[x])) {return 1;}
+	}
+
+	return 0;
+
+}
+
+
+
+// param_num_arr_none
+char mul_float_3_simd_ovfl(Py_ssize_t arraylen, float param, float *data2) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// Initialise the comparison values.
+	datasliceleft = initvec_float(param);
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data2[x],  resultslice);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, resultslice);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data2[x] = param * data2[x];
+		if (!isfinite(data2[x])) {return 1;}
+	}
+
+	return 0;
+
+}
+
+
+
+// param_num_arr_arr
+char mul_float_4_simd_ovfl(Py_ssize_t arraylen, float param, float *data2, float *data3) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+
+	// Initialise the comparison values.
+	datasliceleft = initvec_float(param);
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data3[x],  resultslice);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, resultslice);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data3[x] = param * data2[x];
+		if (!isfinite(data3[x])) {return 1;}
+	}
+
+	return 0;
+
+}
+
+
+
+// param_arr_arr_none
+char mul_float_5_simd_ovfl(Py_ssize_t arraylen, float *data1, float *data2) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data1[x],  resultslice);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, resultslice);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data1[x] = data1[x] * data2[x];
+		if (!isfinite(data1[x])) {return 1;}
+	}
+
+	return 0;
+
+}
+
+
+
+// param_arr_arr_arr
+char mul_float_6_simd_ovfl(Py_ssize_t arraylen, float *data1, float *data2, float *data3) {
+
+	// array index counter. 
+	Py_ssize_t x; 
+
+	// SIMD related variables.
+	Py_ssize_t alignedlength;
+
+	float32x2_t datasliceleft, datasliceright, resultslice, checkslice;
+
+	float checkvecresults[FLOATSIMDSIZE];
+	float checksliceinit[FLOATSIMDSIZE] = {0.0};
+
+	// This is used to check for errors by accumulating non-finite values.
+	checkslice = vld1_f32( checksliceinit);
+
+
+	// Calculate array lengths for arrays whose lengths which are not even
+	// multipes of the SIMD slice length.
+	alignedlength = calcalignedlength(arraylen, FLOATSIMDSIZE);
+
+	// Perform the main operation using SIMD instructions.
+	for (x = 0; x < alignedlength; x += FLOATSIMDSIZE) {
+		// Load the data into the vector register.
+		datasliceleft = vld1_f32( &data1[x]);
+		datasliceright = vld1_f32( &data2[x]);
+		// The actual SIMD operation.
+		resultslice = vmul_f32(datasliceleft, datasliceright);
+		// Store the result.
+		vst1_f32( &data3[x],  resultslice);
+
+		// Check the result. None-finite errors should accumulate.
+		checkslice = vmul_f32(checkslice, resultslice);
+	}
+
+	// Check the results of the SIMD operations. If all is OK then the
+	// results should be all zeros. Any none-finite numbers however will
+	// propagate through and accumulate. 
+	vst1_f32( checkvecresults, checkslice);
+	for (x = 0; x < FLOATSIMDSIZE; x++) {
+		if (!isfinite(checkvecresults[x])) {return 1;}
+	}
+
+	// Get the max value within the left over elements at the end of the array.
+	for (x = alignedlength; x < arraylen; x++) {
+		data3[x] = data1[x] * data2[x];
+		if (!isfinite(data3[x])) {return 1;}
+	}
+
+	return 0;
+
+}
+#endif
+
+/*--------------------------------------------------------------------------- */
