@@ -100,3 +100,28 @@ typedef long long v2di __attribute__ ((vector_size (16)));
 #endif
 
 /*--------------------------------------------------------------------------- */
+
+/*   calcalignedlength
+   Calculate the aligned length of the array. This is the length which is
+   evenly divisible by the SIMD register. Any array elements after this
+   one must be dealt with using non-SIMD clean-up code.
+   arraylen = The length of the array in number of elements.
+   simdwidth = The width of the SIMD registers for this data type.
+   Returns the length of the array which can be processed using SIMD.
+*/
+
+#define calcalignedlength(arraylen, simdwidth) (arraylen - (arraylen % simdwidth))
+
+
+/*   enoughforsimd
+   Calculate whether the array to be processed is big enough to be handled by
+   SIMD. We make the minimum size for this bigger than the actual minimum as
+   the overhead for setting up SIMD does not justify very small arrays. The
+   minimum size used here is arbitrary and was not tested with benchmarks.
+   arraylen = The length of the array in number of elements.
+   simdwidth = The width of the SIMD registers for this data type.
+*/
+
+#define enoughforsimd(arraylen, simdwidth) (arraylen >= (simdwidth * 2))
+
+/*--------------------------------------------------------------------------- */
